Documentation
¶
Overview ¶
package defs contain the distro definitions used by the "images" library
Index ¶
- Variables
- func DistroImageConfig(distroNameVer string) (*distro.ImageConfig, error)
- func ImageConfig(distroNameVer, archName, typeName string, replacements map[string]string) (*distro.ImageConfig, error)
- func ImageTypes(distroNameVer string) (map[string]ImageTypeYAML, error)
- func InstallerConfig(distroNameVer, archName, typeName string, replacements map[string]string) (*distro.InstallerConfig, error)
- func PackageSets(it distro.ImageType, replacements map[string]string) (map[string]rpmmd.PackageSet, error)
- func PartitionTable(it distro.ImageType, replacements map[string]string) (*disk.PartitionTable, error)
- type ImageTypeYAML
Constants ¶
This section is empty.
Variables ¶
var ( ErrImageTypeNotFound = errors.New("image type not found") ErrNoPartitionTableForImgType = errors.New("no partition table for image type") ErrNoPartitionTableForArch = errors.New("no partition table for arch") )
var DataFS fs.FS = data
Functions ¶
func DistroImageConfig ¶
func DistroImageConfig(distroNameVer string) (*distro.ImageConfig, error)
DistroImageConfig returns the distro wide ImageConfig.
Each ImageType gets this as their default ImageConfig.
func ImageConfig ¶
func ImageConfig(distroNameVer, archName, typeName string, replacements map[string]string) (*distro.ImageConfig, error)
ImageConfig returns the image type specific ImageConfig
func ImageTypes ¶ added in v0.146.0
func ImageTypes(distroNameVer string) (map[string]ImageTypeYAML, error)
func InstallerConfig ¶
func InstallerConfig(distroNameVer, archName, typeName string, replacements map[string]string) (*distro.InstallerConfig, error)
InstallerConfig returns the InstallerConfig for the given imgType Note that on conditions the InstallerConfig is fully replaced, do any merging in YAML
func PackageSets ¶
func PackageSets(it distro.ImageType, replacements map[string]string) (map[string]rpmmd.PackageSet, error)
PackageSets loads the PackageSets from the yaml source file discovered via the imagetype.
func PartitionTable ¶
func PartitionTable(it distro.ImageType, replacements map[string]string) (*disk.PartitionTable, error)
PartitionTable returns the partionTable for the given distro/imgType.
Types ¶
type ImageTypeYAML ¶
type ImageTypeYAML = imageType
XXX: this should eventually implement the "distro.ImageType" interface, then we don't need to convert into a fedora/rhel imagetype anymore (those will go away in subsequent refactors)